==> ITALICS_2.10.0.zip: ITALICS/doc/ITALICS.R <==
###################################################
### chunk number 1: 
###################################################
#line 96 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpcO6eJB/R.INSTALLe7179f3/ITALICS/inst/doc/ITALICS.Rnw"
require(ITALICS)
ITALICSDataPATH <- attr(as.environment(match("package:ITALICSData",search())),"path")
load(paste(ITALICSDataPATH,"/data/snpInfo.RData", sep=""))
load(paste(ITALICSDataPATH,"/data/quartetInfo.RData", sep=""))



###################################################
### chunk number 2: 
###################################################
#line 107 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpcO6eJB/R.INSTALLe7179f3/ITALICS/inst/doc/ITALICS.Rnw"
ITALICSDataPATH <- attr(as.environment(match("package:ITALICSData",search())),"path")
filename <- paste(ITALICSDataPATH,"/data/HF0844_Xba.CEL", sep="")

headdetails <- readCelHeader(filename[1])
pkgname <- cleanPlatformName(headdetails[["chiptype"]])

quartetEffectFile <- paste(ITALICSDataPATH,"/data/Xba.QuartetEffect.csv", sep="")
quartetEffect <- read.table(quartetEffectFile, sep=";", header=TRUE)


###################################################
### chunk number 3: 
###################################################
#line 130 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpcO6eJB/R.INSTALLe7179f3/ITALICS/inst/doc/ITALICS.Rnw"
profilSNPXba <- ITALICS(quartet$quartetInfo, snpInfo,
     formule="Smoothing+QuartetEffect+FL+I(FL^2)+I(FL^3)+GC+I(GC^2)+I(GC^3)")



###################################################
### chunk number 4: 
###################################################
#line 140 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpcO6eJB/R.INSTALLe7179f3/ITALICS/inst/doc/ITALICS.Rnw"
data(cytoband)
plotProfile(profilSNPXba, Smoothing="Smoothing", cytoband=cytoband)

==> ITALICS_2.71.0.zip: ITALICS/doc/ITALICS.R <==
### R code from vignette source 'ITALICS.Rnw'

###################################################
### code chunk number 1: ITALICS.Rnw:95-100
###################################################
require(ITALICS)
ITALICSDataPATH <- attr(as.environment(match("package:ITALICSData",search())),"path")
load(paste(ITALICSDataPATH,"/data/snpInfo.RData", sep=""))
load(paste(ITALICSDataPATH,"/data/quartetInfo.RData", sep=""))



###################################################
### code chunk number 2: ITALICS.Rnw:106-114
###################################################
ITALICSDataPATH <- attr(as.environment(match("package:ITALICSData",search())),"path")
filename <- paste(ITALICSDataPATH,"/extdata/HF0844_Xba.CEL", sep="")

headdetails <- readCelHeader(filename[1])
pkgname <- cleanPlatformName(headdetails[["chiptype"]])

quartetEffectFile <- paste(ITALICSDataPATH,"/extdata/Xba.QuartetEffect.csv", sep="")
quartetEffect <- read.table(quartetEffectFile, sep=";", header=TRUE)


###################################################
### code chunk number 3: ITALICS.Rnw:129-132
###################################################
profilSNPXba <- ITALICS(quartet$quartetInfo, snpInfo,
     formule="Smoothing+QuartetEffect+FL+I(FL^2)+I(FL^3)+GC+I(GC^2)+I(GC^3)")



###################################################
### code chunk number 4: ITALICS.Rnw:139-141
###################################################
data(cytoband)
plotProfile(profilSNPXba, Smoothing="Smoothing", cytoband=cytoband)
